import { axisLeft, axisBottom } from 'd3';

export const axes = (selection, options) => {
  const {
    xScale,
    yScale,
    margin,
    width,
    height,
    xAxisLabel = 'X Axis',
    yAxisLabel = 'Y Axis',
    xAxisLabelOffset = 35,
    yAxisLabelOffset = 25,
  } = options;

  const leftArrowSym = ' →';

  // Axes themselves
  selection
    .selectAll('g.y-axis')
    .data([null])
    .join('g')
    .attr('class', 'y-axis')
    .attr('transform', `translate(${margin.left}, 0)`)
    .call(axisLeft(yScale));

  selection
    .selectAll('g.x-axis')
    .data([null])
    .join('g')
    .attr('class', 'x-axis')
    .attr(
      'transform',
      `translate(0, ${height - margin.bottom})`,
    )
    .call(axisBottom(xScale));

  // Axes Labels
  selection
    .selectAll('text.x-axis-label')
    .data([null])
    .join('text')
    .attr('class', 'x-axis-label')
    .attr('x', width / 2)
    .attr('y', height - margin.bottom + xAxisLabelOffset)
    .text(xAxisLabel + leftArrowSym)
    .style('font-family', 'sans-serif')
    .style('font-size', '18')
    .style('font-weight', 'bold')
    .style('text-anchor', 'middle');

  selection
    .selectAll('text.y-axis-label')
    .data([null])
    .join('text')
    .attr('class', 'y-axis-label')
    .attr(
      'transform',
      `translate(${margin.left - yAxisLabelOffset}, ${height / 2}) rotate(-90)`,
    )
    .text(yAxisLabel + leftArrowSym)
    .style('font-family', 'sans-serif')
    .style('font-size', '18')
    .style('font-weight', 'bold')
    .style('text-anchor', 'middle');
}