import {
  extent,
  scaleLinear,
  scaleOrdinal,
  schemeCategory10,
  axisLeft,
  axisBottom,
} from 'd3';
import { axes } from './axes';
import { scatterPlot } from './scatterplot';

export const viz = (selection, options) => {
  const {
    margin,
    width,
    height,
    data,
    xAxisLabel,
    yAxisLabel,
    xValue,
    yValue,
    rValue,
    colorValue,
  } = options;

  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([margin.left, width - margin.right]);
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([height - margin.bottom, margin.top]);

  selection
    .selectAll('rect')
    .data([null])
    .join('rect')
    .attr('x', margin.left)
    .attr('y', margin.top)
    .attr('width', innerWidth)
    .attr('height', innerHeight)
    .attr('fill', '#D6D6D6');

  selection.call(scatterPlot, {
    data,
    xScale,
    yScale,
    xValue,
    yValue,
  });

  selection.call(axes, {
    xScale,
    yScale,
    width,
    height,
    margin,
    xAxisLabel,
    yAxisLabel,
  });

  const marks = data.map((d) => ({
    x: xScale(xValue(d)),
    y: yScale(yValue(d)),
  }));

  selection
    .selectAll('circle')
    .data(marks)
    .join('circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y)
    .attr('r', 10);
};
